//############################################################################
//
// EZFB ~ Linux Frame Buffer API ~
//
// by James Lehman
// james@akrobiz.com
//
// began: Feb. 2001
//
// EZFB is intended to give C programmers an easy-to-use library of functions
// for drawing points, lines and strings of characters into the Linux frame
// buffer. It also provides a means of displaying bitmap images on any portion
// of the screen and capturing the contents of any portion of the screen to
// a standard bitmap graphics file. All of this is embodied in a set of
// functions that are polymorphic with regard to the characteristics of the
// frame buffer and the bitmap files used. In other words, it makes no
// difference what the screen height or width is or what the color depth is,
// all of the function calls are the same and will have appropriate and
// predictable effects.
//
// This software is distributed in the hope that it will be useful, but
// without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose. See the GNU General Public License
// for more details.
//
//############################################################################

#ifndef __EZFB_BITMAP_FUNCTIONS__
#define __EZFB_BITMAP_FUNCTIONS__

//############################################################################
#include "ezfb_types.h"

//############################################################################

//  UTILITY ROUTINES
int     fix_rectangle                  (struct rectangle* area, int max_x, int max_y);
int     dump_rectangle                 (struct rectangle* area, char* message);
int     bmp_dump_header                (struct bitmap_object* bmp_obj, char* file_name, char* message);

//  BITMAP AS MEMORY OBJECT ROUTINES
int     bmp_object_init                (struct bitmap_object* bmp_obj, int xres, int yres, short bpp);
int     bmp_malloc_object              (struct bitmap_object* bmp_obj);
int     bmp_object_put_pixel           (struct bitmap_object* bmp_obj, int x, int y, u_int c);
int     bmp_object_get_pixel           (struct bitmap_object* bmp_obj, int x, int y);
int     bmp_object_line                (struct bitmap_object* bmp_obj, int x1, int y1, int x2, int y2, u_int c);
int     bmp_object_free                (struct bitmap_object* bmp_obj);

// BITMAP OBJECT AND BMP FILE ROUTINES
int     bmp_malloc_object_from_file    (struct bitmap_object* bmp_obj, char* file_name);
int     bmp_open_for_read              (struct bitmap_object* bmp_obj, char* file_name);
int     bmp_read_file_header           (struct bitmap_object* bmp_obj);
int     bmp_read_object_palette        (struct bitmap_object* bmp_obj);
int     bmp_read_object_image          (struct bitmap_object* bmp_obj);
int     bmp_open_for_write             (struct bitmap_object* bmp_obj, char* file_name);
int     bmp_write_file_header          (struct bitmap_object* bmp_obj);
int     bmp_write_object_palette       (struct bitmap_object* bmp_obj);
int     bmp_write_object_image         (struct bitmap_object* bmp_obj);
int     bmp_save_object_as             (struct bitmap_object* bmp_obj, char* file_name);

//  FRAME BUFFER OUTPUT AS BMP FILE ROUTINES
int     bmp_write_palette_from_cmap    (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj);
int     bmp_write_image_from_fb        (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj, struct rectangle* fb_area);
int     bmp_save_fb_as                 (struct frame_buffer_device* fb, char* file_name);
int     bmp_save_fb_area_as            (struct frame_buffer_device* fb, char* file_name, struct rectangle* fb_area);

//  FRAME BUFFER AND BMP MEMORY OBJECT ROUTINES
int     bmp_object_into_fb             (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj);
int     bmp_malloc_object_from_fb      (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj);
int     bmp_object_palette_from_cmap   (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj);
int     bmp_cmap_from_object_palette   (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj);

//  BMP FILE AS INPUT TO FRAMEBUFFER ROUTINES
int     bmp_read_palette_into_cmap     (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj);
int     bmp_read_image_into_fb         (struct frame_buffer_device* fb, struct bitmap_object* bmp_obj, struct rectangle* fb_area, struct rectangle* bmp_area);
int     bmp_open_into_fb               (struct frame_buffer_device* fb, char* file_name);
int     bmp_open_into_fb_at            (struct frame_buffer_device* fb, char* file_name, struct rectangle* fb_area);
int     bmp_open_area_into_fb_at       (struct frame_buffer_device* fb, char* file_name, struct rectangle* fb_area, struct rectangle* bmp_area);
int     bmp_open_into_fb_center        (struct frame_buffer_device* fb, char* file_name);
int     bmp_open_palette_into_fb_cmap  (struct frame_buffer_device* fb, char* file_name);
//############################################################################
#endif

//############################################################################
//////////////////////////////////////////////////////////////////////////////
//############################################################################

