//############################################################################
//
// EZFB ~ Linux Frame Buffer API ~
//
// by James Lehman
// james@akrobiz.com
//
// began: Feb. 2001
//
// EZFB is intended to give C programmers an easy-to-use library of functions
// for drawing points, lines and strings of characters into the Linux frame
// buffer. It also provides a means of displaying bitmap images on any portion
// of the screen and capturing the contents of any portion of the screen to
// a standard bitmap graphics file. All of this is embodied in a set of
// functions that are polymorphic with regard to the characteristics of the
// frame buffer and the bitmap files used. In other words, it makes no
// difference what the screen height or width is or what the color depth is,
// all of the function calls are the same and will have appropriate and
// predictable effects.
//
// This software is distributed in the hope that it will be useful, but
// without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose. See the GNU General Public License
// for more details.
//
//############################################################################

#ifndef __EZFB_COLOR_MAP_FUNCTIONS__
#define __EZFB_COLOR_MAP_FUNCTIONS__

//############################################################################
#include "ezfb_types.h"

//############################################################################
int      get_fb_cmap              (struct frame_buffer_device* fb);
int      set_fb_cmap              (struct frame_buffer_device* fb);
int      get_color_factors        (struct frame_buffer_device* fb);
int      init_fb_cmap             (struct frame_buffer_device* fb, int save_old);
int      clear_fb_cmap            (struct frame_buffer_device* fb);
int      release_fb_cmap          (struct frame_buffer_device* fb);
int      find_black_and_white     (struct frame_buffer_device* fb);
u_int    make_rgb                 (struct frame_buffer_device* fb, u_short r, u_short g, u_short b);
u_short  get_r_from_rgb           (struct frame_buffer_device* fb, u_int rgb);
u_short  get_g_from_rgb           (struct frame_buffer_device* fb, u_int rgb);
u_short  get_b_from_rgb           (struct frame_buffer_device* fb, u_int rgb);
u_short  get_1bit_from_rgb        (u_short r, u_short g, u_short b);
u_short  get_4bit_from_rgb        (u_short r, u_short g, u_short b);
int      set_fb_cmap_to_was       (struct frame_buffer_device* fb);
int      set_fb_cmap_grays        (struct frame_buffer_device* fb);
int      set_fb_cmap_reds         (struct frame_buffer_device* fb);
int      set_fb_cmap_greens       (struct frame_buffer_device* fb);
int      set_fb_cmap_blues        (struct frame_buffer_device* fb);
int      set_fb_cmap_utility      (struct frame_buffer_device* fb);
int      set_fb_cmap_smooth       (struct frame_buffer_device* fb);
int      set_fb_cmap_random       (struct frame_buffer_device* fb);
int      set_fb_cmap_reduction    (struct frame_buffer_device* fb);
void     set_fb_cmap_index        (struct frame_buffer_device* fb, int i, u_short  r, u_short  g, u_short  b);
void     get_fb_cmap_index        (struct frame_buffer_device* fb, int i, u_short* r, u_short* g, u_short* b);
u_short  get_r_from_fb_cmap_index (struct frame_buffer_device* fb, int i);
u_short  get_g_from_fb_cmap_index (struct frame_buffer_device* fb, int i);
u_short  get_b_from_fb_cmap_index (struct frame_buffer_device* fb, int i);
int      cycle_fb_cmap            (struct frame_buffer_device* fb, int from_index, int to_index, int direction);
int      dump_ezfb_colors         (struct frame_buffer_device* fb);
int      dump_ezfb_cmap           (struct frame_buffer_device* fb);
int      dump_fb_cmap_values      (struct frame_buffer_device* fb);
int      dump_fb_cmap_was_values  (struct frame_buffer_device* fb);
int      binfile_fb_cmap          (struct frame_buffer_device* fb, char* file_name);
//############################################################################
#endif

//############################################################################
//////////////////////////////////////////////////////////////////////////////
//############################################################################


















