//############################################################################
//
// EZFB ~ Linux Frame Buffer API ~
//
// by James Lehman
// james@akrobiz.com
//
// began: Feb. 2001
//
// EZFB is intended to give C programmers an easy-to-use library of functions
// for drawing points, lines and strings of characters into the Linux frame
// buffer. It also provides a means of displaying bitmap images on any portion
// of the screen and capturing the contents of any portion of the screen to
// a standard bitmap graphics file. All of this is embodied in a set of
// functions that are polymorphic with regard to the characteristics of the
// frame buffer and the bitmap files used. In other words, it makes no
// difference what the screen height or width is or what the color depth is,
// all of the function calls are the same and will have appropriate and
// predictable effects.
//
// This software is distributed in the hope that it will be useful, but
// without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose. See the GNU General Public License
// for more details.
//
//############################################################################

//############################################################################
#ifndef __EZFB_FRAME_BUFFER_LIB__
#define __EZFB_FRAME_BUFFER_LIB__

//############################################################################
#include "ezfb_types.h"

//############################################################################
//#define MAX_OPEN_FB 8;
//extern struct frame_buffer_device* active_fb_array[MAX_OPEN_FB + 1];

//############################################################################
int    open_fb                (struct frame_buffer_device* fb, char* dev_name);
int    get_fb_var             (struct frame_buffer_device* fb);
int    set_fb_var             (struct frame_buffer_device* fb);
int    get_fb_fix             (struct frame_buffer_device* fb);
int    get_fb_mem             (struct frame_buffer_device* fb, int save_old);
int    find_screen            (struct frame_buffer_device* fb);

int    init_fb_base           (struct frame_buffer_device* fb, char* dev_name, int save_old);
int    init_fb                (struct frame_buffer_device* fb);
int    init_fb_no_save        (struct frame_buffer_device* fb);
int    init_named_fb          (struct frame_buffer_device* fb, char* dev_name);
int    init_named_fb_no_save  (struct frame_buffer_device* fb, char* dev_name);

int    set_fb_bpp             (struct frame_buffer_device* fb, int bpp_wanted);
//int    set_fb_resolution      (struct frame_buffer_device* fb, int new_xres, int new_yres);
int    copy_old_fb            (struct frame_buffer_device* fb);
int    clear_fb               (struct frame_buffer_device* fb);
int    clear_screen           (struct frame_buffer_device* fb);
int    release_fb             (struct frame_buffer_device* fb);
int    dump_fb_fix_screeninfo (struct frame_buffer_device* fb);
int    dump_fb_var_screeninfo (struct frame_buffer_device* fb);
int    dump_ezfb_object       (struct frame_buffer_device* fb);
int    dump_fb_screen_map     (struct frame_buffer_device* fb);
int    dump_fb_virtual_map    (struct frame_buffer_device* fb);
int    binfile_fb_screen_map  (struct frame_buffer_device* fb, char* file_name);
int    binfile_fb_virtual_map (struct frame_buffer_device* fb, char* file_name);
//int    trap_SIGINT            ();
float  random_01              ();

//############################################################################
#endif

//############################################################################
//////////////////////////////////////////////////////////////////////////////
//############################################################################















